pub struct Resolver { /* private fields */ }Expand description
A DNS resolver that queries from a set of upstream DNS sources, while also storing/fetching responses from a cache. This is used by both external client queries as well as internal HTTP client lookups.
Implementations
Sourceimpl Resolver
impl Resolver
pub fn new( cache_tx: Sender<CacheMsg>, upstream_clients: Vec<Box<dyn DnsClient + Send>>, ) -> Self
Sourcepub async fn resolve_str(
&mut self,
host: &String,
port: u16,
get_ipv6: bool,
udp_size: u16,
) -> Result<SocketAddr>
pub async fn resolve_str( &mut self, host: &String, port: u16, get_ipv6: bool, udp_size: u16, ) -> Result<SocketAddr>
A high-level query for getting an A/AAAA record for a given hostname string. This is only for internal host lookups by Kapiti itself via Hyper HTTP clients:
- Host resolution when updating filter files
- Host resolution of DoH upstream servers
Sourcepub async fn resolve_message(
&mut self,
request: &Message,
request_info: &RequestInfo,
response_buffer: &mut BytesMut,
) -> Result<()>
pub async fn resolve_message( &mut self, request: &Message, request_info: &RequestInfo, response_buffer: &mut BytesMut, ) -> Result<()>
A low-level query that accepts and returns raw DNS query payloads. This is only for outside/“real” Kapiti clients.